@@ -60,10 +60,20 @@ build_multi![
     pull_all
     pull_all_by
     pull_all_with
+    pull_at
 
+    to_safe_integer
     to_string
 
     to_lower
+
+    range_right
+    stub_array
+    stub_false
+    stub_object
+    stub_string
+    stub_true
+    to_path
 ];
 
 #[cfg(feature = "lazy_static")]
