@@ -1,11 +1,7 @@
-#[doc(hidden)]
-pub fn add() {
-    todo!()
-}
-#[doc(hidden)]
-pub fn ceil() {
-    todo!()
-}
+mod add;
+pub use add::*;
+mod ceil;
+pub use ceil::*;
 #[doc(hidden)]
 pub fn divide() {
     todo!()
